# nemos 
A toolbox of statistical analysis for neuroscience. 

## Disclaimer
Please note that this package is currently under development. While you can download and test the functionalities that are already present, it's important to be aware that the code stability and systematic testing cannot be guaranteed at this stage. 

See our [README](https://github.com/flatironinstitute/nemos/blob/main/README.md) for more info.
